---
title: Templates
page_title: Templates - DropDownList - Kendo UI for Vue
description: "Customize the content of the suggested list items and the suggested list elements of a Kendo UI DropDownList wrapper for Vue."
slug: templates_dropdownlist
position: 8
---

# Templates

The DropDownList provides full control over the way an item or a popup header is rendered by using the [Kendo UI templates](https://docs.telerik.com/kendo-ui/framework/templates/overview).

## Item Templates

The item template manages the way the list DropDownList items are rendered.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-dropdownlist :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :template="itemTemplate">
    </kendo-dropdownlist>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: "#vueapp",
    data: {
        dataSourceArray: [
            { text: 'Black', value: '1' },
            { text: 'Orange', value: '2' },
            { text: 'Grey', value: '3' }
        ],
        itemTemplate: '<strong>#= value #</strong> - #= text #'
    }
})
```

## Header Templates

The header template manages the way the popup header of the DropDownList is rendered.

```html
<div id="vueapp">
    <kendo-dropdownlist :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :header-template="headerTemplate">
    </kendo-dropdownlist>
</div>
```

```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data: {
        dataSourceArray: [
            { text: 'Black', value: '1' },
            { text: 'Orange', value: '2' },
            { text: 'Grey', value: '3' }
        ],
        headerTemplate: '<strong>Header template</strong>'
    }
})
```

## Footer Templates

The footer template manages the way the popup footer of the DropDownList is rendered. The footer is re-rendered on every change of the Data Source. The context of the template is the component itself.

```html
<div id="vueapp">
    <kendo-dropdownlist :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :footer-template="footerTemplate">
    </kendo-dropdownlist>
</div>
```

```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data: {
        dataSourceArray: [
            { text: 'Black', value: '1' },
            { text: 'Orange', value: '2' },
            { text: 'Grey', value: '3' }
        ],
        footerTemplate: '<strong>Footer template</strong>'
    }
})
```

## No-Data Templates

The no-data template displays a `noDataTemplate` template in the popup when the data source is empty.

> When the `noDataTemplate` option is defined, the component always opens the popup element.

```html
<div id="vueapp">
    <kendo-dropdownlist :data-source="dataSourceArray"
                        :data-text-field="'text'"
                        :data-value-field="'value'"
                        :filter="'contains'"
                        :no-data-template="noDataTemplate">
    </kendo-dropdownlist>
</div>
```

```js
Vue.use(DropdownsInstaller);

new Vue({
    el: '#vueapp',
    data: {
        dataSourceArray: [
            { text: 'Black', value: '1' },
            { text: 'Orange', value: '2' },
            { text: 'Grey', value: '3' }
        ],
        noDataTemplate: '<strong>No data is present</strong>'
    }
})
```

## Suggested Links

* [Kendo UI DropDownList for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/dropdownlist/overview)
* [API Reference of the DropDownList Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdownlist)
