---
title: Overview
page_title: Dropdowns Overview - Components - Kendo UI for Vue
description: "Learn about the Kendo UI wrappers for Vue which are delivered by the Dropdowns package."
slug: overview_dropdowns
position: 0
---

# Dropdowns Overview

The Dropdowns allow you to choose from a predefined list of options.

<div class="row components-overview-list mt-5 mb-5 pb-5 separator-bottom">
    <a href="{% slug overview_autocomplete %}" class="col-12 col-md-8 col-lg-6">
        <svg id="autocomplete" viewbox="0 0 72 72">
            <defs>
                <linearGradient id="gradient" gradientUnits="userSpaceOnUse" x1="-3.8848" y1="56.8728" x2="74.8848" y2="11.3951">
                    <stop  offset="0" style="stop-color:#FF9B5E"/>
                    <stop  offset="8.618834e-02" style="stop-color:#FF8C5D"/>
                    <stop  offset="0.1949" style="stop-color:#FF7F5B"/>
                    <stop  offset="0.3" style="stop-color:#FF7B5B"/>
                    <stop  offset="0.7" style="stop-color:#FF6358"/>
                    <stop  offset="0.7835" style="stop-color:#FC5F59"/>
                    <stop  offset="0.8701" style="stop-color:#F4525E"/>
                    <stop  offset="0.9577" style="stop-color:#E63E65"/>
                    <stop  offset="1" style="stop-color:#DD3169"/>
                </linearGradient>
            </defs>
            <path d="M60,57.5L51.5,66H12V18H6v54h48l12-12V15h-6V57.5z M18,21v6h30l6-6H18z M54,33H18v6h30L54,33z M18,51h18l6-6H18
            V51z M42,3v6h24l6-6H42z M0,0h36v12H0V0z" />
        </svg>
        <div class="h4 mt-3 mb-5">AutoComplete</div>
        <p>A list of suggestions for typed content.</p>
    </a>
    <a href="{% slug overview_combobox %}" class="col-12 col-md-8 col-lg-6">
        <svg id="combobox" viewbox="0 0 72 72">
            <path d="M66,12v48L54,72H12H6v-6V12h6v54h39.5l8.5-8.5V12H66z M18,24h30l6-6H18V24z M54,6h12l6-6H54V6z M0,6h48V0H0V6z
            M18,36h30l6-6H18V36z M18,48h18l6-6H18V48z" />
        </svg>
        <div class="h4 mt-3 mb-5">ComboBox</div>
        <p>A list for picking single items or entering custom values.</p>
    </a>
    <a href="{% slug overview_dropdownlist %}" class="col-12 col-md-8 col-lg-6">
        <svg id="dropdownlist" viewbox="0 0 72 72">
            <path d="M60,57.5L51.5,66H12V12H6v54v6h6h42l12-12V12h-6V57.5z M18,18v6h30l6-6H18z M0,0v6h66l6-6H0z M18,36h30l6-6H18
            V36z M18,48h18l6-6H18V48z" />
        </svg>
        <div class="h4 mt-3 mb-5">DropDownList</div>
        <p>A predefined list of options for picking single values.</p>
    </a>
    <a href="{% slug overview_multicolumncombobox %}" class="col-12 col-md-8 col-lg-6">
        <svg id="multicolumncombobox" viewbox="0 0 72 72">
            <path d="M60,15h6v45l-12,12H6V15h6v51h39.5l8.5-8.5V15z M51,21v3h6l-6,6v6h6l-6,6v6h6l-12,12v-6h-6l-6,6v-6H27l-6,6v-6H18v-6h3v-6
            H18v-6h3v-6H18V24h3V21h6v3h6V21h6v3h6V21H51z M33,42H27v6h6V42z M33,30H27v6h6V30z M45,42h-6v6h6V42z M45,30h-6v6h6V30z M54,3v6h12l6-6H54z
            M48,3H0v6h48V3z"/>
        </svg>
        <div class="h4 mt-3 mb-5">MultiColumnComboBox</div>
        <p>A list for picking single items or entering custom values with table-like drop-down structure.</p>
    </a>
    <a href="{% slug overview_multiselect %}" class="col-12 col-md-8 col-lg-6">
        <svg id="multiselect" viewbox="0 0 72 72">
            <path d="M60,57.5L51.5,66H12V24H6v42v6h6h42l12-12V24h-6V57.5z M54,30H18v6h30L54,30z M0,18h66l6-6H0V18z M18,48h18l6-6
            H18V48z M72,0H30v6h36L72,0z M0,0h24v6H0V0z" />
        </svg>
        <div class="h4 mt-3 mb-5">MultiSelect</div>
        <p>A predefined list of options for multiple item selection.</p>
    </a>
</div>

## Basic Usage

The following example demonstrates how to initialize the AutoComplete, ComboBox, DropDownList, MultiColumnComboBox, and MultiSelect.

{% meta height:550 %}
```html-preview
<div id="vueapp" class="vue-app">
    <div class="col-xs-12 col-sm-6 example-col">
        <p>AutoComplete</p>
        <kendo-autocomplete :data-source="dataSourceArray"
                            :placeholder="'Your favorite sport'"
                            :separator="', '"
                            :filter="'contains'">
        </kendo-autocomplete>
    </div>

    <div class="col-xs-12 col-sm-6 example-col">
        <p>ComboBox</p>
        <kendo-combobox :data-source="dataSourceArray"
                        :filter="'contains'"
                        :index="0">
        </kendo-combobox>
    </div>

    <div class="col-xs-12 col-sm-6 example-col">
        <p>DropDownList</p>
        <kendo-dropdownlist :data-source="dataSourceArray"
                            :index="0">
        </kendo-dropdownlist>
    </div>

    <div class="col-xs-12 col-sm-6 example-col">
        <p>MultiSelect</p>
        <kendo-multiselect :data-source="dataSourceArray"
                           :filter="'contains'">
        </kendo-multiselect>
    </div>

    <div class="col-xs-12 col-sm-6 example-col">
        <p>MultiColumnComboBox</p>
        <kendo-multicolumncombobox :data-source="multiColumnArray"
                                   :filter="'contains'"
                                   :filter-fields="['name']"
                                   :data-text-field="'name'"
                                   :data-value-field="'name'"
                                   :columns="columnsDefinitions">
        </kendo-multicolumncombobox>
    </div>
</div>
```
```js
Vue.use(DropdownsInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            dataSourceArray: [
                'Football',
                'Tennis',
                'Basketball',
                'Baseball',
                'Cricket',
                'Field Hockey',
                'Volleyball'
            ],
            multiColumnArray: [{
                name: 'Andrew Fuller',
                company: 'Progress'
            },{
                name: 'Nancy Davolio',
                company: 'Progress'
            },{
                name: 'Sirma Franks',
                company: 'Progress'
            },{
                name: 'John Waltham',
                company: 'Telerik'
            },{
                name: 'Fritz Dong',
                company: 'Progress'
            }],
            columnsDefinitions: [{
                field: 'name'
            },{
                field: 'company'
            }]
        }
    }
})
```
{% endmeta %}

## Installation

To initialize the Dropdowns, either:

* [Use the CDN service]({% slug using_cdn %}), or
* [Use Webpack](#toc-initializing-with-webpack).

### Initializing with Webpack

1. Install Kendo UI and add a theme.

    ```sh
    npm install --save @progress/kendo-ui
    npm install --save @progress/kendo-theme-default
    ```

1. Install the Kendo UI Dropdowns package for Vue.

    ```sh
    npm install --save @progress/kendo-dropdowns-vue-wrapper
    ```

  The package also exports the following wrappers for individual components:

    * AutoComplete
    * ComboBox
    * DropDownList
    * MultiColumnComboBox
    * MultiSelect

1. Import the Kendo UI packages to the App component. If you use the Kendo UI components more than once in your application, add all Kendo UI-related files to the `main.js` file. If you use the Kendo UI components once in your application, add the Kendo UI-related files the component where they will be referred.

    ```js-no-run
    import '@progress/kendo-ui' // This will import the entire Kendo UI library
    // As an alternative, you could import only the scripts that are used by a specific widget:
    // import '@progress/kendo-ui/js/kendo.autocomplete' // Imports only the AutoComplete script and its dependencies
    // import '@progress/kendo-ui/js/kendo.combobox' // Imports only the ComboBox script and its dependencies
    // import '@progress/kendo-ui/js/kendo.dropdownlist' // Imports only the DropDownList script and its dependencies
    // import '@progress/kendo-ui/js/kendo.multiselect' // Imports only the MultiSelect script and its dependencies
    // import '@progress/kendo-ui/js/kendo.multicolumncombobox' // Imports only the MultiColumnComboBox script and its dependencies

    import '@progress/kendo-theme-default/dist/all.css'

    import { AutoComplete,
             ComboBox,
             DropDownList,
             MultiSelect,
             MultiColumnComboBox,
             MultiColumnComboBoxColumn,
             DropdownsInstaller } from '@progress/kendo-dropdowns-vue-wrapper'

    Vue.use(DropdownsInstaller)

    new Vue({
        el: '#app',
        components: {
            AutoComplete,
            ComboBox,
            DropDownList,
            MultiSelect,
            MultiColumnComboBox,
            MultiColumnComboBoxColumn
        }
    })
    ```

## Suggested Links

* [Get Started with the AutoComplete]({% slug overview_autocomplete %})
* [Get Started with the ComboBox]({% slug overview_combobox %})
* [Get Started with the DropDownList]({% slug overview_dropdownlist %})
* [Get Started with the MultiColumnComboBox]({% slug overview_multicolumncombobox %})
* [Get Started with the MultiSelect]({% slug overview_multiselect %})
